import os
import subprocess
import matplotlib.pyplot as plt

IMGCAT = os.path.expanduser('~/local/bin/imgcat')

def zs_dispFig(imgcat_path=IMGCAT):
    """
    shows a matplotlib plot inline in iTerm by saving
    it to a temporary file, displaying the file and
    then cleaning up.

    Note: This function requires the use of an iTerm
    terminal (available from https://www.iterm2.com)
    and requires that the `imgcat` script is on your
    $PATH. It can be useful when running MATLAB on a
    server when you don't have access to a GUI to
    display figures.

    Copyright (C) 2016 Samuel Albanie
    All rights reserved.
    """

    # save figure as temp image
    im_name = '_tmp.jpeg'

    # switch to png if jpeg is unsupported
    try:
        plt.savefig(im_name)
    except ValueError:
        im_name = '_tmp.png'
        plt.savefig(im_name)

    # display in iterm
    subprocess.call([imgcat_path, "--depth", "iterm2", im_name])

    # clear up
    os.remove(im_name)



import os
import glob
import fnmatch


def get_img_paths_in_dir(image_dir, suffix='jpg'):
    """
    returns list of paths to images in the given
    directory.

    Args:
        image_dir (string): path to the directory
            containing the images
        suffix (string): the suffix used to select
            the images (default is `jpg`)

    Returns:
        [string]: a list of paths

    Note: Hidden system files are ignored
    """
    image_dir = os.path.expanduser(image_dir)
    glob_template = os.path.join(image_dir, '*.{}'.format(suffix))
    paths = glob.glob(glob_template)
    return paths


def get_img_paths_in_subdirs(image_dir, suffix='jpg'):
    """
    returns list of paths to images in the subdirectories
    given of the given directory.

    based on a StackOverflow answer by Johan Dahlin

    Args:
        image_dir (string): path to the directory
            containing the subdirs
        suffix (string): the suffix used to select
            the images (default is `jpg`)

    Returns:
        [string]: a list of paths

    Note: Hidden system files are ignored
    """
    image_dir = os.path.expanduser(image_dir)
    paths = []
    for root, dirnames, fnames in os.walk(image_dir):
        for fname in fnmatch.filter(fnames, '*.{}'.format(suffix)):
            paths.append(os.path.join(root, fname))
    return paths
